#
# spec file for package xorgxrdp
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           xorgxrdp
Version:        0.9.19
Release:        1.4
Summary:        Xorg drivers for xrdp
License:        X11
Group:          System/X11/Utilities
URL:            https://github.com/neutrinolabs/xorgxrdp
Source0:        https://github.com/neutrinolabs/%{name}/releases/download/v%{version}/%{name}-%{version}.tar.gz
Source1:        https://github.com/neutrinolabs/%{name}/releases/download/v%{version}/%{name}-%{version}.tar.gz.asc
Source2:        %{name}.keyring
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  libtool
BuildRequires:  nasm
BuildRequires:  pkgconfig
BuildRequires:  xorg-x11-server-sdk
BuildRequires:  xrdp-devel
BuildRequires:  pkgconfig(xorg-macros)
Requires:       xrdp >= 0.9.1
ExcludeArch:    s390 s390x
%{x11_abi_videodrv_req}
%{x11_abi_xinput_req}
# For Leap 42.x and SLE 12.x <= 12.3, keep to use libXfont-devel
%if 0%{?suse_version} > 1320 || 0%{?sle_version}  > 120300
BuildRequires:  libXfont2-devel
%else
BuildRequires:  libXfont-devel
%endif

%description
This package contains Xorg driver modules for xrdp

%prep
%setup -q

%build
sh ./bootstrap
%configure --disable-static
%make_build

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print

%files
%license COPYING
%doc README.md
%{_libdir}/xorg/modules/drivers/xrdpdev_drv.so
%dir %{_libdir}/xorg/modules/input
%{_libdir}/xorg/modules/input/xrdpkeyb_drv.so
%{_libdir}/xorg/modules/input/xrdpmouse_drv.so
%{_libdir}/xorg/modules/libxorgxrdp.so
%dir %{_sysconfdir}/X11/xrdp
%config %{_sysconfdir}/X11/xrdp/xorg.conf

%changelog
* Tue Dec  6 2022 Dirk Müller <dmueller@suse.com>
- update to 0.9.19:
  * We decided to bump up version from v0.2 to v0.9 to indicate xorgxrdp v0.9
    is compatible with xrdp v0.9.
  * Too fast scroll mitigation
  * see https://github.com/neutrinolabs/xorgxrdp/releases/tag/v0.9.19
* Wed Jan  6 2021 Felix Zhang <fzhang.foss@gmail.com>
- Update to version 0.2.15
  - Give group permission also to disconnect socket (#177)
  - Add logs on socket files deletion failure (#176)
  - Fix bug in killing disconnected sessions (#175)
* Mon Sep 14 2020 Felix Zhang <fzhang.foss@gmail.com>
- Update to version 0.2.14
  + Reduce input lag by using two different delays #166
  + Do not fail randr resize if size not changed #161 #156
- Update the upstream maintainer's keyring
* Thu Mar 12 2020 Felix Zhang <fzhang.foss@gmail.com>
- Update to version 0.2.13
  + Add support for button 8/9 #157
* Wed Dec 11 2019 Felix Zhang <fzhang.foss@gmail.com>
- Update to version 0.2.12
  + Glamor support for hardware acceleration #151
  + Fix some memory leak #152
  + Fix issue on screen resizing #153 neutrinolabs/xrdp#914
* Sat Oct 12 2019 Felix Zhang <fezhang@suse.com>
- Update to version 0.2.11 (jsc#SLE-9612)
  + Fix crash on reconnect when monitors change #121 #147
* Thu Jun 13 2019 Felix Zhang <fezhang@suse.com>
- Update to version 0.2.10
  + Improve reliability killing disconnected sessions
  + Introduce suppress output support (requires upcoming xrdp
    v0.9.11)
* Mon Apr 29 2019 Felix Zhang <fezhang@suse.com>
- BuildRequires libXfont2-devel for SLE12-SP4 and later
* Tue Dec 18 2018 Felix Zhang <fezhang@suse.com>
- Update to version 0.2.9 (jsc#SLE-5926)
  + Add a feature to disconnect idle sessions
  + Disable autorepeat in Xorg, it is done in RDP layer
* Thu Sep 20 2018 fezhang@suse.com
- Update to version 0.2.8
  + Fix invalid memory access issues #124 #125
* Mon Aug  6 2018 fezhang@suse.com
- Add xorg-macros BuildRequires and %%{x11_abi_videodrv_req} and
  %%{x11_abi_xinput_req} to prevent ABI mismatch with Xorg, reported
  and fix suggested by Michal Srb (boo#1103556).
* Tue Jul  3 2018 fezhang@suse.com
- Update to version 0.2.7
  + Build fix #119 #123
* Tue Apr 17 2018 fezhang@suse.com
- Update to version 0.2.6
  + Fix GNOME 3 gnome-settings-daemon crash issue #111
  + Show correct version in Xorg log #114 #115
* Wed Jan 31 2018 ro@suse.de
- Add s390 to excludearch list
* Sat Jan  6 2018 fezhang@suse.com
- Update to version 0.2.5
  + Adjust socket file permission #110
  + Accept display number 0 #106
  + Assembly code refactoring
* Thu Sep 28 2017 fezhang@suse.com
- Update to 0.2.4
  + Implement disconnection by xrdp-dis command #51
* Mon Sep  4 2017 fezhang@suse.com
- Exclude s390x arch
- Specfile cleanup
* Wed Aug 16 2017 ftake@geeko.jp
- Update to 0.2.3
  + Fix X programs crash when reconnecting to xrdp with different
    screen size
- Fix build error for Leap 42.3
  + Use libXfont-devel instead of libXfont2-devel
* Tue Jul 11 2017 fezhang@suse.com
- Add source verification
  + Add xorgxrdp-0.2.2.tar.gz.asc
  + Add xorgxrdp.keyring, from the signer Koichiro IWAO (@metalefty
    on github)
* Fri Jun 23 2017 ftake@geeko.jp
- Update to 0.2.2
  * RemoteFX codec bandwidth optimization for aggressive
    application redraws
  * Code cleanups
* Mon May  1 2017 ftake@geeko.jp
- Initial package
